@@ -11,10 +11,10 @@ from undouble import Undouble
 model = Undouble()
 
 # Import example data
-targetdir = model.import_example(data='flowers')
+# targetdir = model.import_example(data='flowers')
 
 # Importing the files files from disk, cleaning and pre-processing
-model.import_data(targetdir)
+model.import_data(r'D:\REPOS\undouble\undouble\data\flower_images/')
 
 # Compute image-hash
 model.compute_hash(method='phash', hash_size=16)
@@ -28,6 +28,14 @@ model.plot()
 # Move the images
 # model.move()
 
+# %%
+model.plot_hash()
+
+model.plot_hash(filenames=['deson.png', 'deson-copy.png'])
+model.plot_hash(filenames=['NOVA-NA-Dry-Iron-Grey-SDL881739255-1-3a886.jpeg', 'nova-plus-1100-w-amaze-ni-10-original-imaf3qxpabhhdwss.jpeg'])
+
+import pandas as pd
+df = pd.DataFrame(index=[model.results['filenames']], data=model.results['img_hash_hex'], columns=['image_hash_hex'])
 
 # %%
 from clustimage import Clustimage
